==> kea-docs-1:3.0.0-1-aarch64.pkg.tar.xz: usr/share/doc/kea/devel/d2/d0d/message_8h.js <==
var message_8h =
[
    [ "isc::dns::InvalidMessageOperation", "d1/da8/classisc_1_1dns_1_1InvalidMessageOperation.html", "d1/da8/classisc_1_1dns_1_1InvalidMessageOperation" ],
    [ "isc::dns::InvalidMessageSection", "dd/d64/classisc_1_1dns_1_1InvalidMessageSection.html", "dd/d64/classisc_1_1dns_1_1InvalidMessageSection" ],
    [ "isc::dns::InvalidMessageUDPSize", "da/df8/classisc_1_1dns_1_1InvalidMessageUDPSize.html", "da/df8/classisc_1_1dns_1_1InvalidMessageUDPSize" ],
    [ "isc::dns::Message", "d7/d08/classisc_1_1dns_1_1Message.html", "d7/d08/classisc_1_1dns_1_1Message" ],
    [ "isc::dns::MessageTooShort", "de/d34/classisc_1_1dns_1_1MessageTooShort.html", "de/d34/classisc_1_1dns_1_1MessageTooShort" ],
    [ "isc::dns::SectionIterator< T >", "d7/d13/classisc_1_1dns_1_1SectionIterator.html", "d7/d13/classisc_1_1dns_1_1SectionIterator" ],
    [ "isc::dns::ConstMessagePtr", "d6/d63/namespaceisc_1_1dns.html#a3073d5ad9a4d7f84fd798c1a68fcdd2e", null ],
    [ "isc::dns::MessagePtr", "d6/d63/namespaceisc_1_1dns.html#a77117d8f825c492bf70a3810ea3c26cf", null ],
    [ "isc::dns::qid_t", "d6/d63/namespaceisc_1_1dns.html#a459bd8174b87d81c05717d1ff9450c85", null ],
    [ "isc::dns::QuestionIterator", "d6/d63/namespaceisc_1_1dns.html#a4f1f672fc055dcad9a60b45f4ad4168b", null ],
    [ "isc::dns::RRsetIterator", "d6/d63/namespaceisc_1_1dns.html#aeabd4ad7f949bd2e2c318ed3c9c55ec8", null ],
    [ "isc::dns::operator<<", "d6/d63/namespaceisc_1_1dns.html#a9559432c749274c5ab329529412e2b5a", null ]
];

==> kea-docs-1:3.0.2-3-aarch64.pkg.tar.xz: usr/share/doc/kea/devel/d2/d0d/message_8h.js <==
var message_8h =
[
    [ "isc::dns::InvalidMessageOperation", "d1/da8/classisc_1_1dns_1_1InvalidMessageOperation.html", "d1/da8/classisc_1_1dns_1_1InvalidMessageOperation" ],
    [ "isc::dns::InvalidMessageSection", "dd/d64/classisc_1_1dns_1_1InvalidMessageSection.html", "dd/d64/classisc_1_1dns_1_1InvalidMessageSection" ],
    [ "isc::dns::InvalidMessageUDPSize", "da/df8/classisc_1_1dns_1_1InvalidMessageUDPSize.html", "da/df8/classisc_1_1dns_1_1InvalidMessageUDPSize" ],
    [ "isc::dns::Message", "d7/d08/classisc_1_1dns_1_1Message.html", "d7/d08/classisc_1_1dns_1_1Message" ],
    [ "isc::dns::MessageTooShort", "de/d34/classisc_1_1dns_1_1MessageTooShort.html", "de/d34/classisc_1_1dns_1_1MessageTooShort" ],
    [ "isc::dns::SectionIterator&lt; T &gt;", "d7/d13/classisc_1_1dns_1_1SectionIterator.html", "d7/d13/classisc_1_1dns_1_1SectionIterator" ],
    [ "isc::dns::ConstMessagePtr", "d6/d63/namespaceisc_1_1dns.html#a3073d5ad9a4d7f84fd798c1a68fcdd2e", null ],
    [ "isc::dns::MessagePtr", "d6/d63/namespaceisc_1_1dns.html#a77117d8f825c492bf70a3810ea3c26cf", null ],
    [ "isc::dns::qid_t", "d6/d63/namespaceisc_1_1dns.html#a459bd8174b87d81c05717d1ff9450c85", null ],
    [ "isc::dns::QuestionIterator", "d6/d63/namespaceisc_1_1dns.html#a4f1f672fc055dcad9a60b45f4ad4168b", null ],
    [ "isc::dns::RRsetIterator", "d6/d63/namespaceisc_1_1dns.html#aeabd4ad7f949bd2e2c318ed3c9c55ec8", null ],
    [ "isc::dns::operator<<", "d6/d63/namespaceisc_1_1dns.html#a9559432c749274c5ab329529412e2b5a", null ]
];
